# Changelog

<!-- towncrier release notes start -->

## [0.2.0](https://github.com/Nagidal/hatch-semver/tree/0.2.0) - 2022-11-15


### Documentation

- Wrote user and api documentation [#25](https://github.com/Nagidal/hatch-semver/issues/25)


## [0.1.0](https://github.com/Nagidal/hatch-semver/tree/0.1.0) - 2022-11-13


### New Features

- Added inline options for prerelease and build tokens [#23](https://github.com/Nagidal/hatch-semver/issues/23)


### Bugfixes

- Fixed undefined ValeError [#16](https://github.com/Nagidal/hatch-semver/issues/16)
- Can bump prereleases now [#17](https://github.com/Nagidal/hatch-semver/issues/17)
- Can bump builds now [#18](https://github.com/Nagidal/hatch-semver/issues/18)
- Can update version to release [#22](https://github.com/Nagidal/hatch-semver/issues/22)


### Development Details

- Created tests [#19](https://github.com/Nagidal/hatch-semver/issues/19)


## [0.0.8](https://github.com/Nagidal/hatch-semver/tree/0.0.8) - 2022-11-10


### Bugfixes

- Fixed another ValueError when bumping major version [#14](https://github.com/Nagidal/hatch-semver/issues/14)


## [0.0.7](https://github.com/Nagidal/hatch-semver/tree/0.0.7) - 2022-11-10


### Bugfixes

- Fixed NameError when bumping version [#12](https://github.com/Nagidal/hatch-semver/issues/12)


## [0.0.6](https://github.com/Nagidal/hatch-semver/tree/0.0.6) - 2022-11-10


### Bugfixes

- Major version should be bumpable now [#10](https://github.com/Nagidal/hatch-semver/issues/10)


## [0.0.5](https://github.com/Nagidal/hatch-semver/tree/0.0.5) - 2022-11-10

No significant changes.


## [0.0.4](https://github.com/Nagidal/hatch-semver/tree/0.0.4) - 2022-11-10


### Development Details

- Plugin structure is ready, should know how to bump major, minor, patch [#2](https://github.com/Nagidal/hatch-semver/issues/2)


### Documentation

- Better readme, but not final [#8](https://github.com/Nagidal/hatch-semver/issues/8)


## [0.0.3](https://github.com/Nagidal/hatch-semver/tree/0.0.3) - 2022-11-10


### Bugfixes

- Renamed module to hatch_semver [#6](https://github.com/Nagidal/hatch-semver/issues/6)


## [0.0.2](https://github.com/Nagidal/hatch-semver/tree/0.0.2) - 2022-11-10


### Development Details

- Prepared project [#1](https://github.com/Nagidal/hatch-semver/issues/1)


### Bugfixes

- Fixed plugin hook path [#4](https://github.com/Nagidal/hatch-semver/issues/4)


